@@ -2,7 +2,7 @@ gr.survAFTWB <-
 function (thetas) {
     gammas <- thetas[1:ncww]
     alpha <- thetas[ncww + 1]
-    sigma.t <- exp(thetas[ncww + 2])
+    sigma.t <- if (is.null(scaleWB)) exp(thetas[ncww + 2]) else scaleWB
     eta.tw <- as.vector(WW %*% gammas)
     eta.t <- eta.tw + alpha * Y
     eta.s <- alpha * Ys
@@ -12,7 +12,11 @@ function (thetas) {
     Vii <- d * (sigma.t - 1) / Vi - sigma.t * Vi^(sigma.t - 1)
     scgammas <- - colSums(WW * (d + c((p.byt * Vii * Vi) %*% wGH)), na.rm = TRUE)
     scalpha <- - sum((p.byt * (d * Y + Vii * exp.eta.tw * P * rowsum(wk.exp.eta.s * Ys, id.GK, reorder = FALSE))) %*% wGH, na.rm = TRUE)
-    scsigmat <- - sigma.t * sum((p.byt * (d / sigma.t + (d - Vi^sigma.t) * log(Vi))) %*% wGH, na.rm = TRUE)
-    c(scgammas, scalpha, scsigmat)
+    if (is.null(scaleWB)) {
+        scsigmat <- - sigma.t * sum((p.byt * (d / sigma.t + (d - Vi^sigma.t) * log(Vi))) %*% wGH, na.rm = TRUE)
+        c(scgammas, scalpha, scsigmat)
+    } else {
+        c(scgammas, scalpha)
+    }
 }
 
