@@ -2,7 +2,7 @@ initial.surv <-
 function (logT, d, X, method, control, extra = NULL) {
     old <- options(warn = (-1))
     on.exit(options(old))
-    if (method == "ph-GH") {
+    if (method == "Cox-PH-GH") {
         Time <- exp(logT)
         start <- extra$times
         DD <- data.frame(id = extra$id, start = start, Time = Time[extra$id])
@@ -10,8 +10,6 @@ function (logT, d, X, method, control, extra = NULL) {
         event <- ave(d[extra$id], extra$id, FUN = function(x) c(rep(0, length(x) - 1), x[1]))
         WW <- if ((nx <- ncol(X)) == 1) extra$y else cbind(X[extra$id, -nx], extra$y)
         cph <- coxph(Surv(start, stop, event) ~ WW)
-        #dat <- data.frame(Time = exp(logT), d = d)
-        #cph <- coxph(Surv(Time, d) ~ X, data = dat)
         coefs <- coef(cph)
         nk <- length(coefs)
         lambda0 <- basehaz(cph, FALSE)
@@ -42,7 +40,7 @@ function (logT, d, X, method, control, extra = NULL) {
         DD <- data.frame(id = extra$id, start = start, Time = extra$Time[extra$id])
         stop <- unlist(lapply(split(DD, DD$id), function (x) c(x$start[-1], x$Time[1])))
         dd <- extra$d
-        event <- ave(dd[extra$id], extra$id, FUN = function(x) c(rep(0, length(x) - 1), x[1]))
+        event <- ave(dd[extra$id], extra$id, FUN = function (x) c(rep(0, length(x) - 1), x[1]))
         WW <- if ((nx <- ncol(X)) == 1) extra$y else cbind(X[extra$id, -nx], extra$y)
         tdCox <- coxph(Surv(start, stop, event) ~ WW)
         coefs <- tdCox$coefficients
@@ -51,7 +49,20 @@ function (logT, d, X, method, control, extra = NULL) {
         if (nk > 1)
             out$gammas <- coefs[seq_len(nk - 1)]
         out
-    } else if (method == "ch-Laplace" || method == "ch-GH")  {
+    } else if (method == "spline-PH-GH" || method == "spline-PH-Laplace") {
+        dat <- data.frame(Time = exp(logT), d = d)
+        init.fit <- survreg(Surv(Time, d) ~ X, data = dat)
+        coefs <- - init.fit$coef / init.fit$scale
+        nk <- length(coefs)
+        out <- list(alpha = coefs[nk])
+        xi <- 1 / init.fit$scale
+        phi <- exp(coefs[1])
+        logh <- log(phi * xi * exp(logT)^(xi - 1))
+        out$gammas.bs <- as.vector(lm.fit(extra$W2, logh)$coefficients)
+        if (nk > 2)
+            out$gammas <- coefs[-c(1, nk)]
+        out
+    } else if (method == "ch-Laplace" || method == "ch-GH") {
         dat <- data.frame(Time = exp(logT), d = d)
         init.fit <- survreg(Surv(Time, d) ~ X, data = dat)
         coefs <- - coef(init.fit) / init.fit$scale
